@@ -393,11 +393,11 @@ def dep_matcher(doc): #[('svx', [1, 0, 2])]
 es_toks = lambda sid, doc:  [ {'_id': f"{sid}-tok-{t.i}", '_source': {"type":"tok", "src":sid, 'i':t.i, "head":t.head.i, 'lex':t.text, 'lem':t.lemma_, 'pos':t.pos_, 'tag':t.tag_, 'dep':t.dep_, "gpos":t.head.pos_, "glem":t.head.lemma_ } } for t in doc ] 
 def es_postag(doc): 
 	from dic.oneself import oneself 
-	return "_^ " + ' '.join([ f"_{t.pos_}_{t.tag_}" if t.pos_ in ('PROPN','NUM','X','SPACE') else f"{t.text if t.text in ('I') else t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}{oneself.get(t.text.lower(), '')}"  for t in doc]) # uniq by ana #,'PUNCT'
+	return "_^ " + ' '.join([ f"{t.text}_{t.pos_}_{t.tag_}" if t.pos_ in ('PROPN','NUM','X','SPACE','PUNCT') else f"{t.text}_{t.lemma_}_{t.pos_}_{t.tag_}{oneself.get(t.text.lower(), '')}"  for t in doc]) # uniq by ana #,'PUNCT'
 def es_hyb(doc): 
 	from dic.oneself import oneself 
-	arr = [ f"_{t.pos_}_{t.tag_}" if t.pos_ in ('PROPN','NUM','X','SPACE') else f"{t.text if t.text in ('I') else t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}{oneself.get(t.text.lower(), '')}"  for t in doc]
-	return "_^ " + ' '.join( [s if '_PUNCT' in s else f"{s}_*" for s in arr]) # support :  a _* book | a * * book
+	arr = [ f"{t.text}_{t.pos_}_{t.tag_}" if t.pos_ in ('PROPN','NUM','X','SPACE','PUNCT') else f"{t.text}_{t.lemma_}_{t.pos_}_{t.tag_}{oneself.get(t.text.lower(), '')}"  for t in doc]
+	return "_^ " + ' '.join( [s if '_PUNCT' in s else f"{s}_*" for s in arr]) # support :  a _* book | a _* _* book
 
 # added 2023.1.16, not tested yet
 cl_root = lambda t: t.dep_ != 'ROOT' and ( (t.pos_ == 'VERB' and t.tag_ != 'VBN')  or (t.pos_ == 'AUX' and t.lemma_ == 'be') )
@@ -448,7 +448,7 @@ def attach_cl(doc): #2023.1.23
 def skenp_tok(t): 
 	from dic.oneself import oneself 
 	#pair = f"_{t.lemma_}_NP_{t.dep_}" if t.ent_type_ == 'NP' else f"_{t.pos_}_{t.tag_}_{t.dep_}" if t.pos_ in ('PROPN','NUM','X','SPACE','PUNCT') else f"{t.text if t.text in ('I') else t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}{oneself.get(t.text.lower(), '')}_{t.dep_}"
-	pair = f"_{t.lemma_}_NP_{t.dep_}" if (t.ent_type_ == 'NP' and t.lemma_ not in ('that','which')) else f"_{t.pos_}_{t.tag_}_{t.dep_}" if t.pos_ in ('PROPN','NUM','X','SPACE','PUNCT') else f"{t.text if t.text in ('I') else t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}{oneself.get(t.text.lower(), '')}_{t.dep_}"
+	pair = f"_{t.lemma_}_{t.pos_}_NP_{t.dep_}{t.head.i}" if (t.ent_type_ == 'NP' and t.lemma_ not in ('that','which')) else f"_{t.pos_}_{t.tag_}_{t.dep_}{t.head.i}" if t.pos_ in ('PROPN','NUM','X','SPACE','PUNCT') else f"{t.text if t.text in ('I') else t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}{oneself.get(t.text.lower(), '')}_{t.dep_}{t.head.i}"
 	if t.ent_id_.startswith("_CL") and not 'ROOT' in t.ent_id_: pair = pair + t.ent_id_
 	return pair 
 
@@ -816,7 +816,7 @@ postag_func_kp = {  # doc,start, end, tag
 				f"{d[s].lemma_}/VERB|vnp:_{d[s].lemma_} {d[s+1:e].text}",]}}) ,
 	"vp":  lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s].lemma_}:VERB:vp|{d[s].lemma_} {d[s+1].text}", f"{d[s].lemma_}:VERB|vp", f"{d[s+1].lemma_}:{d[s+1].pos_}:vp|_VERB {d[s+1].text}",
-				 f"{d[s].lemma_}/VERB|vp:_{d[s].lemma_} {d[s+1].text}",	] }}) ,
+				 f"{d[s].lemma_}/VERB|vp:_{d[s].lemma_} {d[s+1].text.lower()}",	] }}) ,
 	"vpp": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s].lemma_}:VERB:vpp|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB|vpp"
 				 f"{d[s].lemma_}/VERB|vpp:_{d[s].lemma_} {d[s+1:e].text}", ] }}) ,
@@ -954,9 +954,10 @@ span_NP = lambda sp: " ".join([ "_NP" if t.ent_type_ == 'NP' else t.text.lower()
 def skenp_func_kp(doc, start, end, tag): # skenp_func_kp	= lambda doc, start, end, tag: doc.user_data.update({f"{tag}:{doc[start].lemma_} " + span_NP(doc[start+1:end]) : {"vlem":doc[start].lemma_, "start":start, "end":end, "nac": [f"{doc[start].lemma_}:VERB:{tag}|" +span_NP(doc[start:end] ), f"{doc[start].lemma_}:VERB|{tag}", f"*:VERB|{tag}"]} }) 
 	nac = [f"{doc[start].lemma_}:VERB:{tag}|" +span_NP(doc[start:end] ), f"{doc[start].lemma_}:VERB|{tag}", f"*:VERB|{tag}"]
 	if tag in ('vnpn'): # take _NP into account, added 2023.2.14
-		nac.extend([f"{doc[end-1].text.lower()}:NOUN:{tag}|" +doc[start].lemma_ + " " + span_NP(doc[start+1:end-1]) + " " + doc[end-1].text.lower(), f"{doc[end-1].text.lower()}:NOUN|{tag}", f"*:NOUN|{tag}", f"{doc[end-1].text.lower()}/NOUN|{tag}:" +doc[start].lemma_ + " " + span_NP(doc[start+1:end-1]) + " " + doc[end-1].text.lower()])
+		nac.extend([f"{doc[end-1].text.lower()}:NOUN:{tag}|" +doc[start].lemma_ + " " + span_NP(doc[start+1:end-1]) + " " + doc[end-1].text.lower(), f"{doc[end-1].text.lower()}:NOUN|{tag}", f"*:NOUN|{tag}", f"{doc[end-1].text.lower()}/NOUN|{tag}:_" +doc[start].lemma_ + " " + span_NP(doc[start+1:end-1]) + " " + doc[end-1].text.lower()])
 	if tag in ("vnpe"): # take _NP for granted
-		nac.extend([f"{doc[end-1].lemma_}:VERB:{tag}|" +span_NP(doc[start:end]), f"{doc[end-1].lemma_}:VERB|{tag}", f"*:VERB|{tag}", f"{doc[end-1].lemma_}/VERB|vnpe:_" +span_NP(doc[start:end]),])
+		nac.extend([f"{doc[end-1].lemma_}:VERB:{tag}|" +span_NP(doc[start:end]), f"{doc[end-1].lemma_}:VERB|{tag}", f"*:VERB|{tag}", 
+			f"{doc[end-1].lemma_}/VERB|vnpe:_{doc[start].lemma_} _NP " +doc[start+2:end].text.lower(),])
 	if tag in ("vn"): nac.extend([f"{doc[start].lemma_}/VERB|vn:_{doc[start].lemma_} _NP"])
 	if tag == "vna": nac.extend([f"{doc[start].lemma_}/VERB|vna:_{doc[start].lemma_} _NP _ADJ"])
 	if tag in ("vnn"): nac.extend([f"{doc[start].lemma_}/VERB|vnn:_{doc[start].lemma_} _NP _NP"])
@@ -994,7 +995,7 @@ def kp_born(doc, base:bool=True):
 		[ doc.user_data.update({f"nbe:{t.lemma_} {t.head.text.lower()}[{t.head.i},{t.i}]": {"type":"trp",
 			'nac':[f"{t.lemma_}:{t.pos_}:nbe|{t.head.text.lower()}", f"{t.lemma_}:{t.pos_}|nbe", f"*:{t.pos_}|nbe",  # Smoking is banned. /VBG
 				f"{t.head.text.lower()}:{t.tag_}:nbe|{t.lemma_}", f"{t.head.text.lower()}:{t.tag_}|nbe", f"*:{t.tag_}|nbe",] } }) for t in doc if t.dep_ == 'nsubjpass' and t.head.tag_ == 'VBN' ] # the fate is sealed  / smiling is banned .
-		[ doc.user_data.update({f"vc:{t.head.lemma_}[{t.head.i},{t.i}]": {"type":"trp", 'nac':[f"{t.head.lemma_}:{t.head.pos_}|vc", f"*:{t.head.pos_}|vc", f"{t.head.lemma_}/{t.head.pos_}|vc:{t.head.lemma_} _CL",] } }) for t in doc if t.dep_ == 'ccomp' and t.head.pos_ == 'VERB' ]
+		[ doc.user_data.update({f"vc:{t.head.lemma_}[{t.head.i},{t.i}]": {"type":"trp", 'nac':[f"{t.head.lemma_}:{t.head.pos_}|vc", f"*:{t.head.pos_}|vc", f"{t.head.lemma_}/{t.head.pos_}|vc:_{t.head.lemma_} _CLccomp",] } }) for t in doc if t.dep_ == 'ccomp' and t.head.pos_ == 'VERB' ]
 		[ doc.user_data.update({f"ROOT-{t.tag_}:{t.lemma_}[{t.i}]": {"type":"trp","nac":[f"{t.lemma_}:{t.pos_}|ROOT"]} }) for t in doc if t.dep_ == 'ROOT' ]
 		[ doc.user_data.update({f"xcomp-{t.head.pos_}-{t.tag_}:{t.head.lemma_} {t.text}[{t.head.i},{t.i}]": {"type":"trp", 
 			"nac":[f"{t.head.lemma_}:{t.head.pos_}|xcomp:{t.tag_}", f"{t.head.lemma_}:{t.head.pos_}:xcomp:{t.tag_}|{t.text.lower()}",
