@@ -6,7 +6,7 @@ def run(infile, host:str='172.17.0.1', port:int=3309, db:str='nacp'):
 	name = infile.split('.jsonlg' if '.jsonlg' in infile else '.')[0] 
 	start = time.time()
 	my_conn = pymysql.connect(host=host,port=port,user='root',password='cikuutest!',db=db)
-	print ("started:", infile , name,  flush=True)
+	print ("sntjson-kpsnt started:", infile , name,  flush=True)
 	with my_conn.cursor() as cursor: 
 		cursor.execute(f"drop TABLE if exists {name}_kpsnt")
 		cursor.execute(f"CREATE TABLE if not exists {name}_kpsnt(kp varchar(64) not null primary key, snt varchar(128) not null, cnt int not null default 0, per float not null default 0) engine=myisam  DEFAULT CHARSET=latin1 COLLATE=latin1_bin")
