@@ -3,7 +3,7 @@
 import requests,json, os, math,re,traceback,fire,time
 from elasticsearch import Elasticsearch,helpers
 from collections import	defaultdict, Counter
-import pandas as pd 
+#import pandas as pd # remove dependency 2023.4.7
 import warnings
 warnings.filterwarnings("ignore")
 
@@ -28,6 +28,7 @@ config = {
 					"(^[^_]+)",   # first lex
 					"(_[a-z]+_[VERB|NOUN|ADJ|ADV]+)", # lex_tag_lem_pos , _contact_VERB (VERB|NOUN|ADJ|ADV)
 					"(_[a-z]+_VERB_[VBD|VBP|VBG|VBZ|VB]+_)",  # except VBN, 2023.3.20
+					"(_[a-z]+_VERB_VBN_)", 
 					#"(_[a-zA-Z\\-\\.\\'\\$0-9]+)$",  # remove _NP5,  _NP5 => _NP 
 					"(_[a-zA-Z,\\-\\.\\'\\$\\*]+)",  # _^ _ADJ _, _NOUN _VERB , _open/VERB 
 					#"(_[^\\w]+)_",
@@ -46,6 +47,12 @@ config = {
 					  "replacement": "$2/V",  # _open_VERB_VBD => open/V
 					  "all": False
 					},
+				"postag_filterVBN": {
+					  "type": "pattern_replace",
+					  "pattern": "(^_([a-z]+)(_VERB_VBN)_)",
+					  "replacement": "$2/VBN",  # _open_VERB_VBN => open/VBN
+					  "all": False
+					},
 				"postag_filter2": {
 				  "type": "word_delimiter",
 				  "type_table": [
@@ -78,7 +85,7 @@ config = {
 				}
 			  },
 			  "analyzer": {
-				"postag_ana": {"filter": ["postag_filter", "postag_filterV", "postag_filter1",  "postag_filter2", "unique_filter"], "type": "custom", "tokenizer": "whitespace" }, #"lowercase",
+				"postag_ana": {"filter": ["postag_filter", "postag_filterV", "postag_filterVBN", "postag_filter1",  "postag_filter2", "unique_filter"], "type": "custom", "tokenizer": "whitespace" }, #"lowercase",
 				"path_ana": {"type": "custom", "tokenizer": "path-tokenizer"},
 				"path_ana3": {"type": "custom", "tokenizer": "path-tokenizer3"},
 				"feedback_ana": {"type": "custom", "tokenizer": "feedback-tokenizer"},
@@ -273,6 +280,8 @@ config = {
 			"sc": {"type": "integer" , "index": "false"},
 			"isum": {"type": "integer" , "index": "false"},
 			"md5": { "type": "text", "store": "false", "norms":"false"},
+			"md5snt": { "type": "keyword", "index": "false"},
+			"sntmd5": { "type": "keyword", "index": "false"}, # added 2023.4.4
 			"toks": { "type": "keyword", "index": "false" ,"store": "false"},
 			"snts": { "type": "keyword", "index": "false" },
 			"blob": { "type": "binary", "store": "false"},
@@ -280,6 +289,7 @@ config = {
 			"title": { "type": "text", "analyzer": "standard"},
 			"essay": { "type": "text", "analyzer": "standard"},
 			"body": { "type": "text", "index": "false" },
+			"spacy": { "type": "text", "index": "false" }, # spacy json result 
 			"doc": { "type": "text", "index": "false" },#"doc": { "type": "keyword", "index": "false" ,"store": "false"}, # dim arr of dsk
 			"tm": { "type": "date"}, #"format": "yyyy-MM-dd HH:mm:ss || yyyy-MM-dd || yyyy/MM/dd HH:mm:ss|| yyyy/MM/dd ||epoch_millis"
 			"timestamp": { "type": "date"},
@@ -488,7 +498,7 @@ def testana(index:str='test'):
 	init( index ) 
 	arr = requests.post(f"http://sntvec.wrask.com:9200/{index}/_analyze", json={
   "analyzer": "postag_ana",
-  "text": "booked_book_VERB_VBD_NP5"
+  "text": "booked_book_VERB_VBN_NP5"
 }).json()
 	for t in arr['tokens']:
 		print (t) 
