@@ -1,4 +1,4 @@
-# 2022.6.29 , cp from cikuu/api/uvirun/textacy-fastapi.py  #uvicorn textacy-fastapi:app --reload --port 80 --host 0.0.0.0
+# 2022.6.29 , cp from cikuu/api/uvirun/textacy-fastapi.py  #uvicorn textacy_fastapi:app --reload --host 0.0.0.0
 from uvirun import *
 import textacy,spacy
 if not hasattr(spacy, 'nlp'): spacy.nlp  = spacy.load('en_core_web_sm')
@@ -34,5 +34,34 @@ def textacy_TextStats(text:str="The quick fox jumped over the lazy dog.", divers
 	if readability: res.update({'readability': { d: ts.readability(d) for d in readability.strip().split(',')}})
 	return res
 
+@app.get('/textacy/resources', tags=["textacy"])
+def textacy_resources(w:str="overcome", lang:str='en', sense:str="v", f:str="get_synonyms"): 
+	''' func: get_synonyms/get_antonyms/get_hyponyms '''
+	import textacy.resources
+	if not hasattr(textacy_resources, 'rs'):
+		textacy_resources.rs = textacy.resources.ConceptNet()
+	if f == 'get_synonyms': return textacy_resources.rs.get_synonyms(w, lang=lang, sense=sense)
+	elif f == 'get_antonyms': return textacy_resources.rs.get_antonyms(w, lang=lang, sense=sense)
+	elif f == 'get_hyponyms': return textacy_resources.rs.get_hyponyms(w, lang=lang, sense=sense)
+	
 if __name__ == '__main__': # https://textacy.readthedocs.io/en/latest/quickstart.html
-	print ("result:", textacy_TextStats())
\ No newline at end of file
+	print ("result:", textacy_TextStats())
+	print ( textacy_resources(), flush=True) 
+
+'''
+https://textacy.readthedocs.io/en/latest/api_reference/datasets_resources.html#conceptnet
+>>> import textacy.resources
+>>> rs = textacy.resources.ConceptNet()
+>>> rs.download()
+>>> rs.info
+
+>>> rs.get_synonyms("spouse", lang="en", sense="n")
+['mate', 'married person', 'better half', 'partner']
+>>> rs.get_antonyms("love", lang="en", sense="v")
+['detest', 'hate', 'loathe']
+>>> rs.get_hyponyms("marriage", lang="en", sense="n")
+['cohabitation situation', 'union', 'legal agreement', 'ritual', 'family', 
+
+docker run -d --restart=always --name textacy -p 8009:8000 wrask/textacy uvicorn textacy_fastapi:app --reload --host 0.0.0.0
+
+'''
\ No newline at end of file
